PCI: Rename pci_remove_bus_device to pci_stop_and_remove_bus_device

The old pci_remove_bus_device actually did stop and remove.

Make the name reflect that to reduce confusion.

This patch is done by sed scripts and changes back some incorrect
__pci_remove_bus_device changes.

Suggested-by: Jesse Barnes <jbarnes@virtuousgeek.org>
Signed-off-by: Yinghai Lu <yinghai@kernel.org>
Signed-off-by: Jesse Barnes <jbarnes@virtuousgeek.org>
diff --git a/drivers/pci/remove.c b/drivers/pci/remove.c
index 82f8ae5..7abe67b 100644
--- a/drivers/pci/remove.c
+++ b/drivers/pci/remove.c
@@ -79,7 +79,7 @@
 
 static void __pci_remove_behind_bridge(struct pci_dev *dev);
 /**
  * pci_remove_bus_device - remove a PCI device and any children
  * @dev: the device to remove
  *
  * Remove a PCI device from the device lists, informing the drivers
@@ -102,7 +102,7 @@
 
 	pci_destroy_dev(dev);
 }
-void pci_remove_bus_device(struct pci_dev *dev)
+void pci_stop_and_remove_bus_device(struct pci_dev *dev)
 {
 	pci_stop_bus_device(dev);
 	__pci_remove_bus_device(dev);
@@ -145,7 +145,7 @@
 	struct list_head *l, *n;
 
 	/*
 	 * VFs could be removed by pci_remove_bus_device() in the
 	 *  pci_stop_bus_devices() code path for PF.
 	 *  aka, bus->devices get updated in the process.
 	 * but VFs are inserted after PFs when SRIOV is enabled for PF,
@@ -174,6 +174,6 @@
 	pci_stop_dev(dev);
 }
 
-EXPORT_SYMBOL(pci_remove_bus_device);
+EXPORT_SYMBOL(pci_stop_and_remove_bus_device);
 EXPORT_SYMBOL(pci_remove_behind_bridge);
 EXPORT_SYMBOL_GPL(pci_stop_bus_device);
@@ -79,7 +79,7 @@
 static void __pci_remove_behind_bridge(struct pci_dev *dev);
 /**
- * pci_remove_bus_device - remove a PCI device and any children
+ * pci_stop_and_remove_bus_device - remove a PCI device and any children
  * @dev: the device to remove
  *
@@ -145,7 +145,7 @@
 
 	/*
-	 * VFs could be removed by pci_remove_bus_device() in the
+	 * VFs could be removed by pci_stop_and_remove_bus_device() in the
 	 *  pci_stop_bus_devices() code path for PF.
 	 *  aka, bus->devices get updated in the process.